summaryrefslogtreecommitdiffstats
path: root/src/H5AC.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2003-12-06 20:38:31 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2003-12-06 20:38:31 (GMT)
commit31431be37492b0446c048401bcb9512ae23ef8f4 (patch)
tree9928afd828704483be974f8e2cd8238bbc576869 /src/H5AC.c
parent1b1e1ebbbd5b4d18c5f413e79b58f7f7e782519f (diff)
downloadhdf5-31431be37492b0446c048401bcb9512ae23ef8f4.zip
hdf5-31431be37492b0446c048401bcb9512ae23ef8f4.tar.gz
hdf5-31431be37492b0446c048401bcb9512ae23ef8f4.tar.bz2
[svn-r7917] Purpose:
Code cleanup Description: Clean up compiler warnings, especially the 'FUNC' variable not used which comes out in production mode. Solution: Had to add a new FUNC_ENTER_NOAPI_NOINIT_NOFUNC macro for those non-API functions which don't need the 'FUNC' variable defined. (This will be _so_ much easier when C99 is standard on all our supposed platforms, since it has a __FUNC__ macro... ) Platforms tested: FreeBSD 4.9 (sleipnir) too minor for h5committest (although there were lots of files changed, the change was minor in each one)
Diffstat (limited to 'src/H5AC.c')
-rw-r--r--src/H5AC.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/H5AC.c b/src/H5AC.c
index 6361b0e..0ea967b 100644
--- a/src/H5AC.c
+++ b/src/H5AC.c
@@ -197,7 +197,7 @@ H5AC_init_interface(void)
#endif /* H5_HAVE_PARALLEL */
herr_t ret_value=SUCCEED; /* Return value */
- FUNC_ENTER_NOINIT(H5AC_init_interface)
+ FUNC_ENTER_NOAPI_NOINIT(H5AC_init_interface)
/* Sanity check */
assert(H5P_CLS_DATASET_XFER_g!=(-1));
@@ -305,7 +305,7 @@ H5AC_term_interface(void)
{
int n=0;
- FUNC_ENTER_NOINIT(H5AC_term_interface)
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5AC_term_interface)
if (interface_initialize_g) {
if(H5AC_dxpl_id>0 || H5AC_noblock_dxpl_id>0 || H5AC_ind_dxpl_id>0) {
@@ -486,8 +486,8 @@ H5AC_compare(const void *_a, const void *_b)
H5AC_info_t *slot_b;
int ret_value=0;
- /* Use FUNC_ENTER_NOINIT here to avoid performance issues */
- FUNC_ENTER_NOINIT(H5AC_compare)
+ /* Use FUNC_ENTER_NOAPI_NOINIT here to avoid performance issues */
+ FUNC_ENTER_NOAPI_NOINIT_NOFUNC(H5AC_compare)
assert(current_cache_g);